/*    filelistview.cpp
 *
 * Hively Player file list view. Lots of code borrowed from the PuTTY profile
 * list.
 *
 * Copyright 2007,2008 Petteri Kangaslampi
 *
 * See license.txt for full copyright and license information.
*/

#include <aknviewappui.h>
#include <aknlists.h>
#include <badesca.h>
#include <hivelyplayer.rsg>
#include <akntitle.h>
#include <bautils.h>
#include <f32file.h>
#include <aknnotedialog.h>
#include <stringloader.h>
#include "filelistview.h"
#include "hivelyplayerappui.h"
#include "hivelyplayeruids.hrh"
#include "hivelyplayer.hrh"


_LIT(KListBoxFormat, "\t%S\t\t");
const TInt KListBoxFormatAddLength = 3;

_LIT(KInternalDir, "c:\\hively\\");
_LIT(KCardDir, "e:\\hively\\");


// Factory
CFileListView *CFileListView::NewL() {
    CFileListView *self = new (ELeave) CFileListView;
    CleanupStack::PushL(self);
    self->ConstructL();
    CleanupStack::Pop();
    return self;
}


// Constructor
CFileListView::CFileListView() {
}


// Second-phase constructor
void CFileListView::ConstructL() {
    BaseConstructL(R_HIVELYPLAYER_FILELIST_VIEW);
}


// Destructor
CFileListView::~CFileListView() {
    delete iListBox;
    iListBox = NULL;
    delete iFileArray;
    iFileArray = NULL;
    delete iFileListArray;
    iFileListArray = NULL;
}


// CAknView::Id()
TUid CFileListView::Id() const {
    return TUid::Uid(KUidHivelyPlayerFileListViewDefine);
}


// CAknView::HandleCommandL
void CFileListView::HandleCommandL(TInt aCommand) {
    
    switch ( aCommand ) {

        case ECmdFileListPlay:
            if ( iListBox && (iFileArray->Count() > 0) ) {
                ((CHivelyPlayerAppUi*)AppUi())->ActivatePlaybackView(
                    (*iFileArray)[iListBox->CurrentItemIndex()]);
            }
            break;
            
        default:
            // Forward unknown commands to the app ui
            AppUi()->HandleCommandL(aCommand);
    }
}


// CAknView::DoActivateL
void CFileListView::DoActivateL(const TVwsViewId &aPrevViewId,
                                   TUid /*aCustomMessageId*/,
                                   const TDesC8 & /*aCustomMessage*/) {

    if ( !iFileListArray ) {
        // Arrays not created yet -- starting for the first time.
        InitViewL();
        
    } else {
        // Starting again, coming from the playback view
    }

    // Create the listbox -- this is the only control this view uses, so no
    // separate container needed
    iListBox = new (ELeave) CAknSingleStyleListBox();
    iListBox->ConstructL(NULL); // Creates a window since there is no parent
    iListBox->View()->SetListEmptyTextL(
        *StringLoader::LoadLC(R_HIVELYPLAYER_STR_FILELIST_EMPTY));
    CleanupStack::PopAndDestroy(); // empty text
    iListBox->CreateScrollBarFrameL(ETrue);
    iListBox->ScrollBarFrame()->SetScrollBarVisibilityL(
        CEikScrollBarFrame::EOn, CEikScrollBarFrame::EAuto);
    iListBox->SetRect(ClientRect());
    iListBox->SetListBoxObserver(this);
    iListBox->ActivateL();
    
    // Add files to the listbox
    CTextListBoxModel *lbm = iListBox->Model();
    lbm->SetItemTextArray(iFileListArray);
    lbm->SetOwnershipType(ELbmDoesNotOwnItemArray);
    iListBox->HandleItemAdditionL();

    // Restore old selection, if any
    iListBox->ScrollToMakeItemVisible(iSelectedItem);
    iListBox->SetCurrentItemIndex(iSelectedItem);

    // Activate the UI control
    AppUi()->AddToStackL(iListBox);
    
    // Set title
    HBufC *title = CEikonEnv::Static()->AllocReadResourceL(
        R_HIVELYPLAYER_STR_FILELIST_TITLE);
    CAknTitlePane* titlePane = static_cast<CAknTitlePane*>
        (StatusPane()->ControlL(TUid::Uid(EEikStatusPaneUidTitle)));
    titlePane->SetText(title); //takes ownership

    iListBox->DrawDeferred();
}


// CAknView::DoDeactivate()
void CFileListView::DoDeactivate() {
    
    if ( iListBox) {
        AppUi()->RemoveFromStack(iListBox);
        delete iListBox;
        iListBox = NULL;
    }
}


// CAknView::HandleStatusPaneSizeChange()
void CFileListView::HandleStatusPaneSizeChange() {
    if ( iListBox ) {
        iListBox->SetRect(ClientRect());
    }
}


// Format file name for use in the listbox
HBufC *CFileListView::FormatForListboxLC(const TDesC &aFileName) {

    TParse parsa;
    parsa.SetNoWild(aFileName, NULL, NULL);
    TPtrC name = parsa.Name();
    HBufC *buf = HBufC::NewLC(name.Length() + KListBoxFormatAddLength);
    TPtr p = buf->Des();
    p.Format(KListBoxFormat, &name);
    return buf;
}


// Append a file to both lists
void CFileListView::AppendFileL(const TDesC &aFileName) {
    // Add to file name array
    iFileArray->AppendL(aFileName);
    iFileListArray->AppendL(*FormatForListboxLC(aFileName));
    CleanupStack::PopAndDestroy();
}


// Initialize for the first time
void CFileListView::InitViewL() {
    
    iFileArray = new (ELeave) CDesCArrayFlat(8);
    iFileListArray = new (ELeave) CDesCArrayFlat(8);

    RFs &fs = CEikonEnv::Static()->FsSession();

    // Find all files and add them to the list
    CDir *dir;
    if ( fs.GetDir(KInternalDir, KEntryAttNormal,
                   ESortByName, dir) == KErrNone ) {
        CleanupStack::PushL(dir);
        for ( TInt i = 0; i < dir->Count(); i++ ) {
            TFileName name;
            name = KInternalDir;
            name.Append((*dir)[i].iName);
            AppendFileL(name);
        }
        CleanupStack::PopAndDestroy(); //dir
    }
    if ( fs.GetDir(KCardDir, KEntryAttNormal,
                   ESortByName, dir) == KErrNone ) {
        CleanupStack::PushL(dir);
        for ( TInt i = 0; i < dir->Count(); i++ ) {
            TFileName name;
            name = KCardDir;
            name.Append((*dir)[i].iName);
            AppendFileL(name);
        }
        CleanupStack::PopAndDestroy(); //dir
    }
}


// MEikListBoxObserver::HandleListBoxEventL()
void CFileListView::HandleListBoxEventL(CEikListBox * /*aListBox*/,
                                           TListBoxEvent aEventType) {
    if ( (aEventType == EEventEnterKeyPressed) ||
         (aEventType == EEventItemDoubleClicked) ) {
        HandleCommandL(ECmdFileListPlay);
    }
}
