/*    hivelyplayerappui.cpp
 *
 * Hively Player Application UI class
 *
 * Copyright 2008 Petteri Kangaslampi
 *
 * See license.txt for full copyright and license information.
*/

#include "hivelyplayerappui.h"
#include "filelistview.h"
#include "playbackview.h"
#include "hivelyplayer.hrh"
#include "hivelyplayer.h"
#include "hivelyplayeruids.hrh"
#include <hivelyplayer.rsg>
#include <aknpopup.h>
#include <akngrid.h>
#include <aknlists.h>
#include <aknutils.h>
#include <aknnotewrappers.h>
#include <libc/sys/reent.h>


_LIT(KTune, "c:\\galactic_emeralds.hvl");


CHivelyPlayerAppUi::CHivelyPlayerAppUi() {
}


void CHivelyPlayerAppUi::ConstructL() {
    BaseConstructL(CAknAppUi::EAknEnableSkin);
    
    iPlayer = CHivelyPlayer::NewL(*this);
    iPlayer->SetVolume(50);

    iFileListView = CFileListView::NewL();
    AddViewL(iFileListView);
    iPlaybackView = CPlaybackView::NewL();
    AddViewL(iPlaybackView);

    SetDefaultViewL(*iFileListView);
}


CHivelyPlayerAppUi::~CHivelyPlayerAppUi() {
    delete iPlayer;
    CloseSTDLIB();
}


void CHivelyPlayerAppUi::HandleCommandL(TInt aCommand) {

    switch (aCommand) {
        case EAknSoftkeyBack:
        case EAknSoftkeyExit:
        case EEikCmdExit: {
            Exit();
            break;
        }

        default:
            break;
    }    
}



void CHivelyPlayerAppUi::ActivatePlaybackView(const TDesC &aFileName) {
    iPlayFileName = aFileName;
    ActivateLocalViewL(TUid::Uid(KUidHivelyPlayerPlaybackViewDefine));
}


void CHivelyPlayerAppUi::ActivateFileListView() {
    ActivateLocalViewL(TUid::Uid(KUidHivelyPlayerFileListViewDefine));
}


const TDesC &CHivelyPlayerAppUi::PlayFileName() {
    return iPlayFileName;
}


void CHivelyPlayerAppUi::PlayL(const TDesC &aFileName) {
    iPlayer->PlayL(aFileName, CCoeEnv::Static()->FsSession());
}


void CHivelyPlayerAppUi::Stop() {
    iPlayer->Stop();
}


void CHivelyPlayerAppUi::SetVolume(TInt aVolume) {
    iPlayer->SetVolume(aVolume);
}


CHivelyPlayer *CHivelyPlayerAppUi::Player() {
    return iPlayer;
}


void CHivelyPlayerAppUi::MhpoAudioError(TInt aError) {
    delete iPlayer;
    iPlayer = NULL;

    TBuf<32> buf;
    buf.Format(_L("Audio error %d"), aError);
    CAknInformationNote *note = new (ELeave) CAknInformationNote(ETrue);
    note->SetTone(CAknInformationNote::ENoTone);
    note->SetTimeout(CAknInformationNote::EShortTimeout);
    note->ExecuteLD(buf);    
}


void CHivelyPlayerAppUi::MhpoUnderflow() {
}
