/*    hivelyplayerappui.h
 *
 * Hively Player Application UI class
 *
 * Copyright 2008 Petteri Kangaslampi
 *
 * See license.txt for full copyright and license information.
*/

#ifndef HIVELYPLAYERAPPUI_H
#define HIVELYPLAYERAPPUI_H

#include <aknviewappui.h>
#include "hivelyplayer.h"

// Forward declarations
class CFileListView;
class CPlaybackView;


/**
 * Hively Player Application UI class. Contains the main application logic.
 */
class CHivelyPlayerAppUi : public CAknViewAppUi, public MHivelyPlayerObserver {
    
public:
    void ConstructL();
    CHivelyPlayerAppUi();
    ~CHivelyPlayerAppUi();
    void HandleCommandL(TInt aCommand);

    /** 
     * Activates the playback view, playing a specified file
     * 
     * @param aFileName File name
     */
    void ActivatePlaybackView(const TDesC &aFileName);

    /** 
     * Activates the file list view.
     */
    void ActivateFileListView();

    /** 
     * Gets the file name to be played. Typically called from the playback
     * view only.
     * 
     * @return File to be played.
     */
    const TDesC &PlayFileName();

    /** 
     * Starts playing a file.
     * 
     * @param aFileName File name
     */
    void PlayL(const TDesC &aFileName);

    /** 
     * Stops playing if a tune is currently playing.
     */
    void Stop();

    /** 
     * Sets the playback volume
     * 
     * @param aVolume Volume, in percentage: 0 for silence, 100 for max
     */
    void SetVolume(TInt aVolume);

    /** 
     * Gets a pointer to the player currently playing. Does not transfer
     * ownership.
     * 
     * @return Pointer to the current player or NULL if one doesn't exist.
     */
    CHivelyPlayer *Player();

private: // MHivelyPlayerObserver
    void MhpoAudioError(TInt aError);
    void MhpoUnderflow();       

private:
    CFileListView *iFileListView;
    CPlaybackView *iPlaybackView;
    CHivelyPlayer *iPlayer;
    TFileName iPlayFileName;
};


#endif
