/*    playbackcontainer.cpp
 *
 * Hively Player container class for the playback view. Some code borrowed from
 * the PuTTY terminal container.
 *
 * Copyright 2002,2004,2007-2008 Petteri Kangaslampi
 *
 * See license.txt for full copyright and license information.
*/

#include <e32std.h>
#include <gdi.h>
#include <eikenv.h>
#include <apgtask.h>
#include <eikspane.h>
#include <eikbtgpc.h>
#include <eikmenub.h>
#include <eiklabel.h>
#include <aknsbasicbackgroundcontrolcontext.h>
#include <aknnotewrappers.h> 
#include <aknsskininstance.h>
#include <aknsutils.h>
#include <aknsdrawutils.h>
#include <stringloader.h>
#include "hivelyplayerappui.h"
#include "playbackview.h"
#include "playbackcontainer.h"
#include "hivelyplayer.h"
#include "hivelyplayer.hrh"
#include <hivelyplayer.rsg>

_LIT(KAssertPanic, "playbackcontainer.cpp");
#define assert(x) __ASSERT_ALWAYS(x, User::Panic(KAssertPanic, __LINE__))


// Factory method
CPlaybackContainer *CPlaybackContainer::NewL(const TRect &aRect,
                                             CPlaybackView *aView,
                                             CHivelyPlayer *aPlayer) {
    
    CPlaybackContainer *self = new (ELeave) CPlaybackContainer(aView, aPlayer);
    CleanupStack::PushL(self);
    self->ConstructL(aRect);
    CleanupStack::Pop(self);
    return self;
}


// Constructor
CPlaybackContainer::CPlaybackContainer(CPlaybackView *aView,
                                       CHivelyPlayer *aPlayer)
    : iView(aView),
      iPlayer(aPlayer) {
}


// Desctructor
CPlaybackContainer::~CPlaybackContainer() {
    delete iTitleLabel;
    delete iBackground;
}


// Second-phase constructor
void CPlaybackContainer::ConstructL(const TRect &aRect) {   
    CreateWindowL();

    // Get label color from the current skin
    MAknsSkinInstance *skin = AknsUtils::SkinInstance();
    TRgb color;
    AknsUtils::GetCachedColor(skin, color, KAknsIIDQsnTextColors,
                              EAknsCIQsnTextColorsCG9);

    // Build the title label
    iTitleLabel = new (ELeave) CEikLabel;
    iTitleLabel->SetContainerWindowL(*this);
    iTitleLabel->SetTextL(*(StringLoader::LoadLC(
                                R_HIVELYPLAYER_STR_PLAYBACK_TITLE_LABEL,
                                *(iPlayer->TitleLC()))));
    CleanupStack::PopAndDestroy(2); // text, title
    iTitleLabel->OverrideColorL(EColorLabelText, color);
    
    SetRect(aRect);

    iBackground = CAknsBasicBackgroundControlContext::NewL(
        KAknsIIDQsnBgAreaMain, Rect(), EFalse);
}


void CPlaybackContainer::Draw(const TRect &aRect) const {

    CWindowGc &gc = SystemGc();

    // Draw skin background
    MAknsSkinInstance *skin = AknsUtils::SkinInstance();
    MAknsControlContext *cc = AknsDrawUtils::ControlContext(this);
    AknsDrawUtils::Background(skin, cc, this, gc, aRect);
}


TInt CPlaybackContainer::CountComponentControls() const {
    return 1;
}


CCoeControl *CPlaybackContainer::ComponentControl(TInt aIndex) const {
    
    switch ( aIndex ) {
        case 0:
            return iTitleLabel;

        default:
            assert(EFalse);
    }

    return NULL;
}


TKeyResponse CPlaybackContainer::OfferKeyEventL(const TKeyEvent &aKeyEvent,
                                                TEventCode aType) {

    if ( aType == EEventKey ) {        
        switch ( aKeyEvent.iCode ) {            
            case EKeyLeftArrow:
                iView->HandleCommandL(ECmdPlaybackDecVolume);
                return EKeyWasConsumed;
                
            case EKeyRightArrow:
                iView->HandleCommandL(ECmdPlaybackIncVolume);
                return EKeyWasConsumed;
        }
    }    
    
    return EKeyWasNotConsumed;
}


void CPlaybackContainer::SizeChanged() {

    TRect conRect = Rect();
    
    TInt y = 20;

    TSize size = iTitleLabel->MinimumSize();
    if ( size.iWidth > conRect.Width() ) {
        size.iWidth = conRect.Width();
    }
    TInt fontHeight = (3*iTitleLabel->Font()->FontMaxHeight()) / 2;
    if ( size.iHeight < fontHeight ) {
        size.iHeight = fontHeight;
    }
    TInt x = (conRect.Width() / 2) - (size.iWidth / 2);
    iTitleLabel->SetRect(TRect(TPoint(x, y), size));
    
    DrawDeferred();
}


TTypeUid::Ptr CPlaybackContainer::MopSupplyObject(TTypeUid aId) {
    if ( iBackground && (aId.iUid == MAknsControlContext::ETypeId) ) {
        return MAknsControlContext::SupplyMopObject(aId, iBackground);
    }
    return CCoeControl::MopSupplyObject(aId);   
}
