/*    playbackcontainer.h
 *
 * Hively Player container class for the playback view. Some code borrowed from
 * the PuTTY terminal container.
 *
 * Copyright 2002,2004,2007-2008 Petteri Kangaslampi
 *
 * See license.txt for full copyright and license information.
*/

#ifndef PLAYBACKCONTAINER_H
#define PLAYBACKCONTAINER_H

#include <coecntrl.h>

class CEikLabel;
class CAknsBasicBackgroundControlContext;
class CHivelyPlayer;


/**
 * Hively Player playback container class. Owns playback-related controls.
 */
class CPlaybackContainer : public CCoeControl {
    
public:
    /** 
     * Factory method.
     *
     * @param aRect Initial playback container screen rectangle
     * @param aView The view that owns this container
     * @param aPlayer The Hively Player engine instance to use for metadata
     * 
     * @return A new CPlaybackContainer instance.
     */
    static CPlaybackContainer *NewL(const TRect &aRect,
                                    CPlaybackView *aView,
                                    CHivelyPlayer *aPlayer);

    /** 
     * Destructor.
     */
    ~CPlaybackContainer();
    
public: // From CCoeControl
    TInt CountComponentControls() const;
    CCoeControl *ComponentControl(TInt aIndex) const;
    TKeyResponse OfferKeyEventL(const TKeyEvent &aKeyEvent,
                                TEventCode aType);
    void Draw(const TRect &aRect) const;
    void SizeChanged();
    TTypeUid::Ptr MopSupplyObject(TTypeUid aId);
    
private:
    // Constructor
    CPlaybackContainer(CPlaybackView *aView, CHivelyPlayer *aPlayer);

    // Second-phase Constructor
    void ConstructL(const TRect &aRect);
    
    CPlaybackView *iView;
    CEikLabel *iTitleLabel;
    CAknsBasicBackgroundControlContext *iBackground;
    CHivelyPlayer *iPlayer;
};

#endif
