/*    playbackview.cpp
 *
 * Hively Player playback view.
 *
 * Copyright 2007,2008 Petteri Kangaslampi
 *
 * See license.txt for full copyright and license information.
*/

#include <aknviewappui.h>
#include <aknlists.h>
#include <badesca.h>
#include <hivelyplayer.rsg>
#include <akntitle.h>
#include <bautils.h>
#include <f32file.h>
#include <aknnotedialog.h>
#include <stringloader.h>
#include <aknvolumecontrol.h>
#include <aknnavi.h>
#include <aknnavide.h>
#include "playbackview.h"
#include "playbackcontainer.h"
#include "hivelyplayerappui.h"
#include "hivelyplayeruids.hrh"
#include "hivelyplayer.hrh"


// Factory
CPlaybackView *CPlaybackView::NewL() {
    CPlaybackView *self = new (ELeave) CPlaybackView;
    CleanupStack::PushL(self);
    self->ConstructL();
    CleanupStack::Pop();
    return self;
}


// Constructor
CPlaybackView::CPlaybackView() {
}


// Second-phase constructor
void CPlaybackView::ConstructL() {
    BaseConstructL(R_HIVELYPLAYER_PLAYBACK_VIEW);
    iVolume = 5;
    ((CHivelyPlayerAppUi*)AppUi())->SetVolume(10*iVolume);
}


// Destructor
CPlaybackView::~CPlaybackView() {
    if ( iNaviPane ) {
        iNaviPane->Pop(NULL);
    }
    delete iNaviDecorator;
    delete iContainer;
}


// CAknView::Id()
TUid CPlaybackView::Id() const {
    return TUid::Uid(KUidHivelyPlayerPlaybackViewDefine);
}


// CAknView::HandleCommandL
void CPlaybackView::HandleCommandL(TInt aCommand) {
    
    switch ( aCommand ) {

        case ECmdPlaybackDecVolume:
            if ( iVolume > 1 ) {
                iVolume--;
                ((CHivelyPlayerAppUi*)AppUi())->SetVolume(10*iVolume);
                if ( iVolumeControl ) {
                    iVolumeControl->SetValue(iVolume);
                }
            }
            break;
                
        case ECmdPlaybackIncVolume:
            if ( iVolume < 10 ) {
                iVolume++;
                ((CHivelyPlayerAppUi*)AppUi())->SetVolume(10*iVolume);
                if ( iVolumeControl ) {
                    iVolumeControl->SetValue(iVolume);
                }
            }
            break;
                
        case EAknSoftkeyBack:
            ((CHivelyPlayerAppUi*)AppUi())->ActivateFileListView();
            break;

        default:
            // Forward unknown commands to the app ui
            AppUi()->HandleCommandL(aCommand);
    }
}


// CAknView::DoActivateL
void CPlaybackView::DoActivateL(const TVwsViewId & /*aPrevViewId*/,
                                   TUid /*aCustomMessageId*/,
                                   const TDesC8 & /*aCustomMessage*/) {

    // Start playing
    ((CHivelyPlayerAppUi*)AppUi())->PlayL(
        ((CHivelyPlayerAppUi*)AppUi())->PlayFileName());

    // Create a container for the UI controls
    iContainer = CPlaybackContainer::NewL(
        ClientRect(), this, ((CHivelyPlayerAppUi*)AppUi())->Player());
    iContainer->SetMopParent(this);
    iContainer->ActivateL();
    AppUi()->AddToStackL(iContainer);

    // Set title
    HBufC *title = CEikonEnv::Static()->AllocReadResourceL(
        R_HIVELYPLAYER_STR_PLAYBACK_TITLE);
    CAknTitlePane* titlePane = static_cast<CAknTitlePane*>
        (StatusPane()->ControlL(TUid::Uid(EEikStatusPaneUidTitle)));
    titlePane->SetText(title); //takes ownership

    // Create a volume indicator in the navi pane
    iNaviPane = static_cast<CAknNavigationControlContainer*>
        (StatusPane()->ControlL(TUid::Uid(EEikStatusPaneUidNavi)));
    iNaviDecorator = iNaviPane->CreateVolumeIndicatorL(
        R_AVKON_NAVI_PANE_VOLUME_INDICATOR);
    iVolumeControl = static_cast<CAknVolumeControl*>
        (iNaviDecorator->DecoratedControl());
    iVolumeControl->SetValue(iVolume);
    iNaviPane->PushL(*iNaviDecorator);    
}


// CAknView::DoDeactivate()
void CPlaybackView::DoDeactivate() {
    if ( iNaviPane ) {
        iNaviPane->Pop(NULL);
    }
    iNaviPane = NULL;
    delete iNaviDecorator;
    iNaviDecorator = NULL;
    iVolumeControl = NULL;
    ((CHivelyPlayerAppUi*)AppUi())->Stop();
    if ( iContainer ) {
        AppUi()->RemoveFromStack(iContainer);
    }
    delete iContainer;
    iContainer = NULL;
}


// CAknView::HandleStatusPaneSizeChange()
void CPlaybackView::HandleStatusPaneSizeChange() {
    if ( iContainer ) {
        iContainer->SetRect(ClientRect());
    }
}
